@@ -27,7 +27,7 @@ plugins {
     `freemarker-root`
     `maven-publish`
     signing
-    id("biz.aQute.bnd.builder") version "6.1.0"
+    id("biz.aQute.bnd.builder") version "7.0.0"
     id("eclipse")
 }
 
@@ -144,6 +144,9 @@ tasks.sourcesJar.configure {
         into("META-INF")
     }
 
+    exclude("freemarker/core/_Java9Impl.java")
+    exclude("freemarker/core/_Java16Impl.java")
+
     // Depend on the createBuildInfo task and include the generated file
     dependsOn(createBuildInfo)
     from(buildInfoFile())
@@ -344,9 +347,7 @@ publishing {
 
                 packaging = "jar"
                 name.set("Apache FreeMarker")
-                description.set("""
-
-                    Google App Engine compliant variation of FreeMarker.
+                description.set("\n" + """
                     FreeMarker is a "template engine"; a generic tool to generate text output based on templates.
                     """.trimIndent().prependIndent("    ") + "\n  "
                 )
